# -*- coding: utf-8 -*-
# Generated by Django 1.10.3 on 2016-11-24 23:55


import django.db.models.deletion
import django.utils.timezone
from django.db import migrations, models

import model_utils.fields


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0007_auto_20161109_1511'),
    ]

    operations = [
        migrations.CreateModel(
            name='EnterpriseCustomerIdentityProvider',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', model_utils.fields.AutoCreatedField(default=django.utils.timezone.now, editable=False, verbose_name='created')),
                ('modified', model_utils.fields.AutoLastModifiedField(default=django.utils.timezone.now, editable=False, verbose_name='modified')),
                ('provider_id', models.SlugField(help_text='Slug field containing a unique identifier for the identity provider.', unique=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.RemoveField(
            model_name='enterprisecustomer',
            name='identity_provider',
        ),
        migrations.RemoveField(
            model_name='historicalenterprisecustomer',
            name='identity_provider',
        ),
        migrations.AddField(
            model_name='enterprisecustomeridentityprovider',
            name='enterprise_customer',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='enterprise_customer_identity_provider', to='enterprise.EnterpriseCustomer'),
        ),
    ]
